
# Slot: object




URI: [biolink:gene_to_expression_site_association_object](https://w3id.org/biolink/vocab/gene_to_expression_site_association_object)

## Domain and Range

[GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md) ->  <sub>REQ</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md)
